#!/bin/bash

rm -f calib.txt
if [ ! -f data.m_sigma ];then
 lib/find_candidates_MAG_SIGMA_MAG.sh
fi

if [ -z $1 ] ;then
 echo "Performing manual magnitude calibration."
 echo "Please specify the comparison stars and their magnitudes!
Opening the reference image..."
 ./pgfv calib
else
 # Magnitude calibration for BVRri bands using APASS magnitudes from UCAC4
 BAND=$1
 case "$BAND" in
 "C")
 ;;
 "B")
 ;;
 "V")
 ;;
 "R")
 ;;
 "r")
 ;;
 "i")
 ;;
 *) 
  echo "ERROR: unknown band $BAND"
  exit 1
 esac
 
 echo "Performing automatic magnitude calibration using $BAND APASS magnitudes from the UCAC4 catalog."
 
 if [ ! -f vast_summary.log ];then
  echo "ERROR: cannot find vast_summary.log file!"
  exit 1
 fi

 grep "Ref.  image: " vast_summary.log &>/dev/null
 if [ $? -ne 0 ];then
  echo "ERROR: cannot parse vast_summary.log file!"
  exit 1
 fi 
 
 REFERENCE_IMAGE=`grep "Ref.  image: " vast_summary.log  |awk '{print $6}'`
 if ! util/solve_plate_with_UCAC4 $REFERENCE_IMAGE $2 ;then
  echo "Sorry, the reference image could not be solved... :("
  exit 1
 fi
 UCAC4_REFERENCE_IMAGE_MATCH_FILE=wcs_`basename $REFERENCE_IMAGE`.cat.ucac4


 case "$BAND" in
 "C")
  cat $UCAC4_REFERENCE_IMAGE_MATCH_FILE | awk '{print $8" "$11" "sqrt($9*$9+$12*$12)}' | sort -n > calib.txt
 ;;
 "B")
  cat $UCAC4_REFERENCE_IMAGE_MATCH_FILE | awk '{print $8" "$13" "sqrt($9*$9+$14*$14)}' | sort -n > calib.txt
 ;;
 "V")
  cat $UCAC4_REFERENCE_IMAGE_MATCH_FILE | awk '{print $8" "$15" "sqrt($9*$9+$16*$16)}' | sort -n > calib.txt
 ;;
 "r")
  cat $UCAC4_REFERENCE_IMAGE_MATCH_FILE | awk '{print $8" "$17" "sqrt($9*$9+$18*$18)}' | sort -n > calib.txt
 ;;
 "i")
  cat $UCAC4_REFERENCE_IMAGE_MATCH_FILE | awk '{print $8" "$19" "sqrt($9*$9+$20*$20)}' | sort -n > calib.txt
 ;;
 "R")
  cat $UCAC4_REFERENCE_IMAGE_MATCH_FILE | awk '{print $8" "$21" "sqrt($9*$9+$22*$22)}' | sort -n > calib.txt
 ;;
 *) 
  echo "ERROR: unknown band $BAND"
  exit 1
 esac

fi

echo "Saving a copy of calib.txt in calib.txt_backup"
cp calib.txt calib.txt_backup
util/calibrate_magnitude_scale `lib/fit_mag_calib`
lib/find_candidates_MAG_SIGMA_MAG.sh
echo "done =)"
